@@ -1,4 +1,5 @@
 from typing import Union, Any
+from pydantic import Field
 
 from .fields import Path, Header, Query, Body, Form, FormURLEncoded, File
 
@@ -22,3 +23,7 @@ class ParamSignature():
     
     def __repr__(self) -> str:
         return f"ParamSignature(name={self._name}, type={self._type}, default={self._default}, param_object={self.param_object})"
+    
+    @property
+    def field(self):
+        return self.param_object
\ No newline at end of file
