@@ -11,6 +11,7 @@ from pydantic import BaseModel, create_model
 from .flask_swagger_ui import get_swaggerui_blueprint
 from ..params import ParamsType, FormType, ParamSignature, Header, Path, Query, Body, Form, FormURLEncoded, File
 from ..routing import APIRouter, EndpointDefinition
+from ..security import HTTPSecurityBase, HTTPScheme
 
 
 class SwaggerGenerator(Blueprint):
@@ -81,7 +82,8 @@ class SwaggerGenerator(Blueprint):
             "servers": [{"url": s} for s in servers],
             "paths":{},
             "components":{
-                "schemas":{}
+                "schemas":{},
+                "securitySchemes":{}
             },
             "security":[]
         }
@@ -169,6 +171,10 @@ class SwaggerGenerator(Blueprint):
                         if "requestBody" not in self.template["paths"][ep.rule][ep.method]:
                             self.template["paths"][ep.rule][ep.method]["requestBody"] = {"content":{}}
                         self.template["paths"][ep.rule][ep.method]["requestBody"]["content"].update(final_form_schema)
+
+                        ## define security scheme
+                        if ep.security:
+                            self.template["paths"][ep.rule][ep.method]["security"] = [ep.security.schema]
                         
         if self.additional_path:
             self.template["paths"].update(self.additional_path)
@@ -176,6 +182,8 @@ class SwaggerGenerator(Blueprint):
             self.template["components"] = self.additional_components
         if self.additional_components_schema:
             self.template["components"]["schemas"] = self.additional_components_schema
+        if HTTPSecurityBase.all_schemes:
+            self.template["components"]["securitySchemes"] = HTTPSecurityBase.all_schemes
         return self.template
     
     def generate_parameter_sub_schema(self, key: str, param_object: ParamsType):
